/*
 * Copyright (C) 2023 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.customization.picker.clock.ui.viewmodel

import android.content.res.Resources
import com.android.customization.module.CustomizationInjector
import com.android.wallpaper.R
import com.android.wallpaper.module.InjectorProvider

class ClockCarouselItemViewModel(val clockId: String, val isSelected: Boolean) {

    /** Description for accessibility purposes when a clock is selected. */
    fun getContentDescription(resources: Resources): String {
        val clockContent =
            (InjectorProvider.getInjector() as? CustomizationInjector)
                ?.getClockDescriptionUtils(resources)
                ?.getDescription(clockId)
                ?: ""
        return resources.getString(R.string.select_clock_action_description, clockContent)
    }
}
